aboutsummaryrefslogtreecommitdiff
blob: ecc69a7964bd624698065fed0cfea28285e2fa15 (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
Add Libera.Chat to ERC services

This backports and consolidates the following commits from upstream git:

commit 86e4d770a833538f3cb711eb42d8fd8d764a4635
Author: Amin Bandali <bandali@gnu.org>
Date:   Mon May 24 23:25:27 2021 -0400

    * lisp/erc/erc-services.el: Fix newly-added Libera.Chat entry (bug#48529).

commit a70a344941713baf08dc0c093bdf25cf36b09858
Author: Corwin Brust <corwin@bru.st>
Date:   Mon May 24 23:36:01 2021 +0200

    Add Libera.chat to `erc-nickserv-alist'

--- emacs-27.2/lisp/erc/erc-services.el
+++ emacs-27.2/lisp/erc/erc-services.el
@@ -32,8 +32,8 @@
 
 ;; As a default, ERC has the data for the official nickname services on
 ;; the networks Austnet, BrasNET, Dalnet, freenode, GalaxyNet, GRnet,
 ;; and Slashnet.  You can add more by using M-x customize-variable RET
 ;; erc-nickserv-alist.
 
 ;; Usage:
 ;;
@@ -190,6 +190,7 @@
 			(const GalaxyNet)
 			(const GRnet)
 			(const iip)
+			(const Libera.Chat)
 			(const OFTC)
 			(const QuakeNet)
 			(const Rizon)
@@ -257,6 +258,15 @@
      "type\\s-/squery\\s-Trent\\s-identify\\s-<password>"
      "Trent@anon.iip"
      "IDENTIFY" nil "SQUERY" nil)
+    (Libera.Chat
+     "NickServ!NickServ@services.libera.chat"
+     ;; Libera.Chat also accepts a password at login, see the `erc'
+     ;; :password argument.
+     "This\\s-nickname\\s-is\\s-registered.\\s-Please\\s-choose"
+     "NickServ"
+     "IDENTIFY" nil nil
+     ;; See also the 901 response code message.
+     "You\\s-are\\s-now\\s-identified\\s-for\\s-")
     (OFTC
      "NickServ!services@services.oftc.net"
      ;; OFTC's NickServ doesn't ask you to identify anymore.
@@ -32,8 +32,8 @@
 ;; As a default, ERC has the data for the official nickname services on
 ;; the networks Austnet, BrasNET, Dalnet, freenode, GalaxyNet, GRnet,
-;; and Slashnet.  You can add more by using M-x customize-variable RET
-;; erc-nickserv-alist.
+;; Libera.Chat and Slashnet.  You can add more by using
+;;   M-x customize-variable RET erc-nickserv-alist.
 
 ;; Usage: